document.addEventListener('DOMContentLoaded', () => {
    const searchBar = document.getElementById('search-bar');
    const recipesList = document.getElementById('recipes-list');
    const modal = document.getElementById('recipe-modal');
    const modalContent = {
        name: document.getElementById('modal-recipe-name'),
        image: document.getElementById('modal-recipe-image'),
        ingredients: document.getElementById('modal-recipe-ingredients'),
        instructions: document.getElementById('modal-recipe-instructions'),
    };
    const closeModal = document.querySelector('.close');

    const recipes = [
         {
            name: 'Espresso',
            ingredients: ['Espresso beans', 'Water'],
             instructions: '1. Grind espresso beans finely.\n2. Load the portafilter and tamp down the grounds.\n3. Lock the portafilter into the espresso machine.\n4. Extract espresso using hot water under high pressure.',
        image: 'coffee/espresso.jpg'
        },
        {
            name: 'Latte',
            ingredients: ['Espresso', 'Steamed milk', 'Foam'],
            instructions: 'Combine espresso and steamed milk, top with foam.',
            image: 'coffee/latte.jpg'
        },
        {
            name: 'Cappuccino',
            ingredients: ['Espresso', 'Steamed milk', 'Foamed milk'],
            instructions: 'Combine espresso with equal parts steamed and foamed milk.',
            image: 'coffee/capuccino.jpg'
        },
        {
            name: 'Americano',
            ingredients: ['Espresso', 'Hot water'],
            instructions: 'Add hot water to espresso.',
            image: 'coffee/americano.jpg'
        },
        {
            name: 'Macchiato',
            ingredients: ['Espresso', 'Foam'],
            instructions: 'Add a small amount of foam to espresso.',
            image: 'coffee/macchiato.jpg'
        },
        {
            name: 'Mocha',
            ingredients: ['Espresso', 'Steamed milk', 'Chocolate syrup', 'Whipped cream'],
            instructions: 'Combine espresso, steamed milk, and chocolate syrup, top with whipped cream.',
            image: 'coffee/mocha.jpg'
        },
        {
            name: 'Flat White',
            ingredients: ['Espresso', 'Steamed milk'],
            instructions: 'Combine espresso with steamed milk, creating a creamy texture.',
            image: 'coffee/flat_white.jpg'
        },
        {
            name: 'Affogato',
            ingredients: ['Espresso', 'Vanilla ice cream'],
            instructions: 'Pour hot espresso over a scoop of vanilla ice cream.',
            image: 'coffee/affogato.jpg'
        },
        {
            name: 'Cortado',
            ingredients: ['Espresso', 'Warm milk'],
            instructions: 'Combine espresso with equal parts warm milk.',
            image: 'coffee/cortado.jpg'
        },
        {
            name: 'Red Eye',
            ingredients: ['Coffee', 'Espresso'],
            instructions: 'Add a shot of espresso to a cup of brewed coffee.',
            image: 'coffee/red_eye.jpg'
        },
        {
            name: 'Black Eye',
            ingredients: ['Coffee', 'Double shot of espresso'],
            instructions: 'Add two shots of espresso to a cup of brewed coffee.',
            image: 'coffee/black_coffee.jpg'
        },
        {
            name: 'Irish Coffee',
            ingredients: ['Hot coffee', 'Irish whiskey', 'Sugar', 'Cream'],
            instructions: 'Combine hot coffee, Irish whiskey, and sugar, top with cream.',
            image: 'coffee/irish_coffee.jpg'
        },
        {
            name: 'Turkish Coffee',
            ingredients: ['Finely ground coffee', 'Water', 'Sugar (optional)', 'Cardamom (optional)'],
            instructions: 'Brew coffee with water and sugar/cardamom in a cezve.',
            image: 'coffee/turkish_coffee.jpg'
        },
        {
            name: 'Cold Brew',
            ingredients: ['Coarsely ground coffee', 'Cold water'],
            instructions: 'Steep coffee in cold water for 12-24 hours, then filter.',
            image: 'coffee/cold_brew.jpg'
        },
        {
            name: 'Nitro Cold Brew',
            ingredients: ['Cold brew coffee', 'Nitrogen'],
            instructions: 'Infuse cold brew coffee with nitrogen and serve.',
            image: 'coffee/nitro_cold_brew.jpg'
        },
        {
            name: 'Frappuccino',
            ingredients: ['Coffee', 'Milk', 'Ice', 'Flavoring syrup', 'Whipped cream'],
            instructions: 'Blend coffee, milk, ice, and flavoring syrup, top with whipped cream.',
            image: 'coffee/frappuccino.jpg'
        },
        {
            name: 'Vienna Coffee',
            ingredients: ['Strong coffee', 'Whipped cream'],
            instructions: 'Top strong coffee with whipped cream.',
            image: 'coffee/vienna_coffee.jpg'
        },
        {
            name: 'Dalgona Coffee',
            ingredients: ['Instant coffee', 'Sugar', 'Hot water', 'Milk'],
            instructions: 'Whip instant coffee, sugar, and hot water until frothy, pour over milk.',
            image: 'coffee/dalgona_coffee.jpg'
        },
        {
            name: 'Frappe',
            ingredients: ['Instant coffee', 'Sugar', 'Water', 'Milk', 'Ice'],
            instructions: 'Blend instant coffee, sugar, water, milk, and ice.',
            image: 'coffee/frappe.jpg'
        },
        {
            name: 'Mazagran',
            ingredients: ['Coffee', 'Lemon juice', 'Ice'],
            instructions: 'Mix coffee with lemon juice and ice.',
            image: 'coffee/mazagran.jpg'
        },
        {
            name: 'Palazzo',
            ingredients: ['Espresso', 'Sugar', 'Lemon peel'],
            instructions: 'Mix espresso with sugar and lemon peel.',
            image: 'coffee/palazzo.jpg'
        },
        {
            name: 'Galao',
            ingredients: ['Espresso', 'Steamed milk'],
            instructions: 'Combine espresso with three parts steamed milk.',
            image: 'coffee/galao.jpg'
        },
        {
            name: 'Espresso con Panna',
            ingredients: ['Espresso', 'Whipped cream'],
            instructions: 'Top espresso with whipped cream.',
            image: 'coffee/espresso_con_panna.jpg'
        },
        {
            name: 'Affogato al Caffe',
            ingredients: ['Espresso', 'Gelato'],
            instructions: 'Pour hot espresso over a scoop of gelato.',
            image: 'coffee/affogato_al_caffe.jpg'
        },
        {
            name: 'Coffee Milkshake',
            ingredients: ['Coffee', 'Ice cream', 'Milk', 'Chocolate syrup'],
            instructions: 'Blend coffee, ice cream, milk, and chocolate syrup.',
            image: 'coffee/coffee_milkshake.jpg'
        },
        {
            name: 'Coffee Smoothie',
            ingredients: ['Coffee', 'Banana', 'Greek yogurt', 'Honey', 'Ice'],
            instructions: 'Blend coffee, banana, Greek yogurt, honey, and ice.',
            image: 'coffee/coffee_smoothie.jpg'
        },
        {
            name: 'Coffee Granita',
            ingredients: ['Strong coffee', 'Sugar', 'Water'],
            instructions: 'Freeze coffee, sugar, and water mixture, scrape to form granita.',
            image: 'coffee/coffee_granita.jpg'
        },
        {
            name: 'Cafe au Lait',
            ingredients: ['Brewed coffee', 'Steamed milk'],
            instructions: 'Combine brewed coffee with steamed milk.',
            image: 'coffee/cafe_au_lait.jpg'
        },
        {
            name: 'Ristretto',
            ingredients: ['Espresso beans', 'Water'],
            instructions: 'Brew a short shot of espresso.',
            image: 'coffee/ristretto.jpg'
        },
        {
            name: 'Long Black',
            ingredients: ['Espresso', 'Hot water'],
            instructions: 'Pour espresso over hot water.',
            image: 'coffee/long_black.jpg'
        },
        {
            name: 'Lungo',
            ingredients: ['Espresso beans', 'Water'],
            instructions: 'Brew an espresso with more water to make it longer.',
            image: 'coffee/lungo.jpg'
        },
        {
            name: 'Espresso Romano',
            ingredients: ['Espresso', 'Lemon'],
            instructions: 'Serve espresso with a slice of lemon.',
            image: 'coffee/espresso_romano.jpg'
        },
        {
            name: 'Cuban Coffee',
            ingredients: ['Espresso', 'Sugar'],
            instructions: 'Brew espresso with sugar.',
            image: 'coffee/cuban_coffee.jpg'
        },
        {
            name: 'Bicerin',
            ingredients: ['Espresso', 'Hot chocolate', 'Whipped cream'],
            instructions: 'Layer espresso, hot chocolate, and whipped cream.',
            image: 'coffee/bicerin.jpg'
        },
        {
            name: 'Café Cubano',
            ingredients: ['Espresso', 'Sugar'],
            instructions: 'Brew espresso with sugar, whisk until frothy.',
            image: 'coffee/cafe_cubano.jpg'
        },
        {
            name: 'Café de Olla',
            ingredients: ['Coffee', 'Cinnamon', 'Piloncillo'],
            instructions: 'Brew coffee with cinnamon and piloncillo (Mexican unrefined sugar).',
            image: 'coffee/cafe_de_olla.jpg'
        },
        {
            name: 'Egg Coffee',
            ingredients: ['Coffee', 'Egg yolk', 'Condensed milk'],
            instructions: 'Whisk egg yolk with condensed milk, pour over coffee.',
            image: 'coffee/egg_coffee.jpg'
        }
    ];

    const renderRecipes = (recipes) => {
        recipesList.innerHTML = '';
        recipes.forEach(recipe => {
            const recipeItem = document.createElement('li');
            recipeItem.classList.add('recipe-item');
            recipeItem.innerHTML = `
                <img src="${recipe.image}" alt="${recipe.name}" class="recipe-thumbnail">
                <span>${recipe.name}</span>
                <br>
                <span>${recipe.ingredients.join(', ')}</span>
            `;
            recipeItem.addEventListener('click', () => {
                modalContent.name.textContent = recipe.name;
                modalContent.image.src = recipe.image;
                modalContent.image.alt = recipe.name;
                modalContent.ingredients.innerHTML = recipe.ingredients.map(ingredient => `<li>${ingredient}</li>`).join('');
                modalContent.instructions.textContent = recipe.instructions;
                modal.style.display = 'block';
            });
            recipesList.appendChild(recipeItem);
        });
    };

    searchBar.addEventListener('input', (e) => {
        const searchTerm = e.target.value.toLowerCase();
        const filteredRecipes = recipes.filter(recipe => recipe.name.toLowerCase().includes(searchTerm));
        renderRecipes(filteredRecipes);
    });

    closeModal.addEventListener('click', () => {
        modal.style.display = 'none';
    });

    window.addEventListener('click', (e) => {
        if (e.target == modal) {
            modal.style.display = 'none';
        }
    });

    renderRecipes(recipes);
});
